summaryrefslogtreecommitdiffstats
path: root/kresources/groupwise/soap/stdsoap2.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/groupwise/soap/stdsoap2.cpp')
-rw-r--r--kresources/groupwise/soap/stdsoap2.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kresources/groupwise/soap/stdsoap2.cpp b/kresources/groupwise/soap/stdsoap2.cpp
index dd43419b..dd2ac010 100644
--- a/kresources/groupwise/soap/stdsoap2.cpp
+++ b/kresources/groupwise/soap/stdsoap2.cpp
@@ -3316,7 +3316,7 @@ again:
{ short v;
unsigned int k = soap->omode; /* make sure we only parse HTTP */
size_t n = soap->count; /* save the content length */
- soap->omode &= ~SOAP_ENC; /* tqmask IO and ENC */
+ soap->omode &= ~SOAP_ENC; /* mask IO and ENC */
soap->omode |= SOAP_IO_BUFFER;
soap_begin_send(soap);
DBGLOG(TEST, SOAP_MESSAGE(fdebug, "Connecting to proxy server\n"));
@@ -3337,7 +3337,7 @@ again:
return SOAP_INVALID_SOCKET;
soap->omode = k;
k = soap->imode;
- soap->imode &= ~SOAP_ENC; /* tqmask IO and ENC */
+ soap->imode &= ~SOAP_ENC; /* mask IO and ENC */
v = soap->version; /* preserve */
if (soap_begin_recv(soap))
return SOAP_INVALID_SOCKET;
@@ -6957,7 +6957,7 @@ SOAP_FMAC2
soap_string_out(struct soap *soap, const char *s, int flag)
{ register const char *t;
register soap_wchar c;
- register soap_wchar tqmask = 0xFFFFFF80UL;
+ register soap_wchar mask = 0xFFFFFF80UL;
#ifdef WITH_DOM
if ((soap->mode & SOAP_XML_DOM) && soap->dom)
{ soap->dom->data = soap_strdup(soap, s); /* check EOM */
@@ -6965,7 +6965,7 @@ soap_string_out(struct soap *soap, const char *s, int flag)
}
#endif
if (soap->mode & SOAP_C_UTFSTRING)
- tqmask = 0;
+ mask = 0;
t = s;
while ((c = *t++))
{ switch (c)
@@ -7028,7 +7028,7 @@ soap_string_out(struct soap *soap, const char *s, int flag)
}
#endif
#endif
- if (c & tqmask)
+ if (c & mask)
{ if (soap_send_raw(soap, s, t - s - 1) || soap_pututf8(soap, (unsigned char)c))
return soap->error;
s = t;